==> haskell-conduit-combinators-1.0.3.1-12-armv7h.pkg.tar.xz: usr/share/haskell/haskell-conduit-combinators/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit-combinators
version: 1.0.3.1
id: conduit-combinators-1.0.3.1-ead600e25193f3b7aaa67fcc85ee2132
key: condu_6YVbyPeNK09FsUErfBNST0
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/fpco/conduit-combinators
synopsis: Commonly used conduit functions, for both chunked and unchunked data
description:
    Provides a replacement for Data.Conduit.List, as well as a convenient Conduit module.
category: Data, Conduit
author: Michael Snoyman
exposed: True
exposed-modules:
    Conduit Data.Conduit.Combinators Data.Conduit.Combinators.Internal
    Data.Conduit.Combinators.Stream
hidden-modules: Data.Conduit.Combinators.Unqualified
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-combinators-1.0.3.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-combinators-1.0.3.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/conduit-combinators-1.0.3.1
hs-libraries: HSconduit-combinators-1.0.3.1-6YVbyPeNK09FsUErfBNST0
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base16-bytestring-0.1.1.6-2ce49c0fdad8d57abae997bf0287241a
    base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    chunked-data-0.2.0-58ae738dfc85ce16f60338cfe67845f2
    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
    conduit-extra-1.1.11-ff8bfc3f034dbe9a6e5b1cd3f1929886
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
    mono-traversable-0.10.1.1-d8076f94d0f4a1c39fe9d5feae3b294a
    mwc-random-0.13.4.0-5fa3ad33ef5e7f15e9e572967b6dc242
    primitive-0.6.1.0-013c88e6ffae491f11ac3b8c0552ce0e
    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
    unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
    unix-compat-0.4.1.4-baa19ce04d0e8a47661438a80ea2aec8
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
    void-0.7.1-5298c6b3a32576797627b9b87532f9cb
haddock-interfaces: /usr/share/doc/haskell-conduit-combinators/html/conduit-combinators.haddock
haddock-html: /usr/share/doc/haskell-conduit-combinators/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conduit-combinators-1.0.3.1-14-armv7h.pkg.tar.xz: usr/share/haskell/haskell-conduit-combinators/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit-combinators
version: 1.0.3.1
id: conduit-combinators-1.0.3.1-1a8f798e0e5afa4c3be6aadf393ed2f9
key: condu_GdjNJ2E2jgTBakfnJEwCLC
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/fpco/conduit-combinators
synopsis: Commonly used conduit functions, for both chunked and unchunked data
description:
    Provides a replacement for Data.Conduit.List, as well as a convenient Conduit module.
category: Data, Conduit
author: Michael Snoyman
exposed: True
exposed-modules:
    Conduit Data.Conduit.Combinators Data.Conduit.Combinators.Internal
    Data.Conduit.Combinators.Stream
hidden-modules: Data.Conduit.Combinators.Unqualified
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-combinators-1.0.3.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-combinators-1.0.3.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/conduit-combinators-1.0.3.1
hs-libraries: HSconduit-combinators-1.0.3.1-GdjNJ2E2jgTBakfnJEwCLC
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base16-bytestring-0.1.1.6-2ce49c0fdad8d57abae997bf0287241a
    base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    chunked-data-0.2.0-58ae738dfc85ce16f60338cfe67845f2
    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
    conduit-extra-1.1.12.1-34a75d65f1bcf0a6ace65de178beb2df
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
    mono-traversable-0.10.1.1-d8076f94d0f4a1c39fe9d5feae3b294a
    mwc-random-0.13.4.0-5fa3ad33ef5e7f15e9e572967b6dc242
    primitive-0.6.1.0-013c88e6ffae491f11ac3b8c0552ce0e
    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
    unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
    unix-compat-0.4.1.4-baa19ce04d0e8a47661438a80ea2aec8
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
    void-0.7.1-5298c6b3a32576797627b9b87532f9cb
haddock-interfaces: /usr/share/doc/haskell-conduit-combinators/html/conduit-combinators.haddock
haddock-html: /usr/share/doc/haskell-conduit-combinators/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
